@@ -19,6 +19,11 @@ class ONTSwapStatus(enum.Enum):
     cancelled = 'cancelled'
 
 
+class ONTMigrationType(enum.Enum):
+    normal = 'normal'
+    subsequent_owner = 'subsequent_owner'
+
+
 class ONTMigrationStatus(enum.Enum):
     pending = 'pending'
     started = 'started'
@@ -143,6 +148,7 @@ class ONTMIGRATION(Base):
     __tablename__ = 'ont_migration'
 
     id = Column(Integer, primary_key=True)
+    migration_type = Column(Enum(ONTMigrationType), nullable=False, default='normal')
     migration_status = Column(Enum(ONTMigrationStatus), default='pending')
     sn = Column(String(length=64), nullable=False, comment='ONT SN')
     ont_type = Column(Enum(CPEProvTypeENUM), nullable=False)
